@@ -12,7 +12,7 @@ extractPrediction <- function(
    trainX <- object[[1]]$trainingData[,!(names(object[[1]]$trainingData) %in% ".outcome")]
    trainY <- object[[1]]$trainingData$.outcome  
 
-   if(object[[1]]$method %in% c("svmradial", "svmpoly", "ctree", "cforest"))
+   if(object[[1]]$method %in% c("svmradial", "svmpoly", "ctree", "ctree2", "cforest"))
    {
       obsLevels <- switch(object[[1]]$method,
          svmradial =, svmpoly =
