@@ -71,12 +71,14 @@ modelLookup <- function(model = NULL)
                            "lm",
                            "lda",
                            "ctree",
+                           "ctree2",
                            "cforest",
                            "ada", "ada", "ada",
                            "glmboost", "glmboost",
                            "gamboost", "gamboost",
                            "blackboost", "blackboost",
-                           "nnet", "nnet", 
+                           "nnet", "nnet",
+                           "pcaNNet", "pcaNNet",
                            "multinom", 
                            "rda", "rda", 
                            "gbm", "gbm", "gbm",
@@ -109,11 +111,13 @@ modelLookup <- function(model = NULL)
                            "parameter",
                            "parameter",         
                            "mincriterion",
+                           "maxdepth",
                            "mtry",
                            "iter", "maxdepth", "nu",
                            "mstop", "prune",
                            "mstop", "prune", 
                            "mstop", "maxdepth",                    
+                           "size", "decay",
                            "size", "decay", 
                            "decay", 
                            "gamma", "lambda", 
@@ -137,7 +141,7 @@ modelLookup <- function(model = NULL)
                            "nprune", "degree", 
                            "nprune", "degree",                    
                            "nprune", "degree",
-                           "lambda", "fraction",
+                           "fraction","lambda", 
                            "fraction",
                            "parameter",
                            "parameter"
@@ -147,11 +151,13 @@ modelLookup <- function(model = NULL)
                            "none",
                            "none",         
                            "P-Value Threshold",
+                           "Max Tree Depth",
                            "#Randomly Selected Predictors",
                            "#Trees", "Max Tree Depth", "Learning Rate",
                            "# Boosting Iterations", "AIC Prune?",
                            "# Boosting Iterations", "AIC Prune?",    
                            "#Trees", "Max Tree Depth",                        
+                           "#Hidden Units", "Weight Decay",
                            "#Hidden Units", "Weight Decay", 
                            "Weight Decay", 
                            "Gamma", "Lambda", 
@@ -175,7 +181,7 @@ modelLookup <- function(model = NULL)
                            "#Retained Terms", "Product Degree",
                            "#Retained Terms", "Product Degree",                  
                            "#Retained Terms", "Product Degree",
-                           "Lambda", "Fraction of Full Solution",
+                           "Fraction of Full Solution","Weight Decay",
                            "Fraction of Full Solution",
                            "none",
                            "none"
@@ -187,10 +193,12 @@ modelLookup <- function(model = NULL)
                            FALSE,
                            TRUE,
                            FALSE,
+                           FALSE,
                            FALSE,   FALSE,   FALSE,
                            TRUE,    FALSE,
                            TRUE,    FALSE,   
                            TRUE,    FALSE,                        
+                           FALSE,   FALSE,
                            FALSE,   FALSE, 
                            FALSE, 
                            FALSE,   FALSE, 
@@ -214,7 +222,7 @@ modelLookup <- function(model = NULL)
                            FALSE,   FALSE, 
                            FALSE,   FALSE,                 
                            FALSE,   FALSE,
-                           FALSE,   TRUE,
+                           TRUE,    FALSE,
                            TRUE,
                            FALSE,              # sdda
                            FALSE
@@ -225,10 +233,12 @@ modelLookup <- function(model = NULL)
                            FALSE,
                            TRUE,
                            TRUE,
+                           TRUE,
                            FALSE,   FALSE,   FALSE,
                            TRUE,    TRUE,
                            TRUE,    TRUE,
                            TRUE,    TRUE,
+                           TRUE,    TRUE,
                            TRUE,    TRUE, 
                            FALSE, 
                            FALSE,   FALSE, 
@@ -265,11 +275,13 @@ modelLookup <- function(model = NULL)
                            TRUE,
                            TRUE,
                            TRUE,
+                           TRUE,
                            TRUE,    TRUE,    TRUE,
                            TRUE,    TRUE,
                            TRUE,    TRUE,
                            TRUE,    TRUE,
-                           TRUE,    TRUE, 
+                           TRUE,    TRUE,
+                           TRUE,    TRUE,
                            TRUE, 
                            TRUE,    TRUE, 
                            TRUE,    TRUE,    TRUE,        
@@ -303,12 +315,14 @@ modelLookup <- function(model = NULL)
                            FALSE,            #   lm
                            TRUE,             #   lda
                            TRUE,             #   ctree (1)
+                           TRUE,             #   ctree2
                            TRUE,             #   cforest (1)
                            TRUE, TRUE,       #   ada (3)
                            TRUE, TRUE,       #   glmboost (2)
                            TRUE, TRUE,       #   gamboost (2)
                            TRUE, TRUE,       #   blackboost (2)
                            TRUE, TRUE,       #   nnet (2)
+                           TRUE, TRUE,       #   pcaNNet (2)
                            TRUE,             #   multinom (1) 
                            TRUE, TRUE,       #   rda (2)
                            TRUE, TRUE, TRUE, #   gbm (3)         
@@ -500,7 +514,7 @@ tuneScheme <- function(model, grid, useOOB = FALSE)
                    seqParam[[i]] <- data.frame(.mstop = subStops[subStops != loop$.mstop[i]])
                  }        
              },
-             enet =, lasso = 
+             enet = 
              {
                grid <- grid[order(grid$.lambda, grid$.fraction, decreasing = TRUE),, drop = FALSE]
                
@@ -517,6 +531,12 @@ tuneScheme <- function(model, grid, useOOB = FALSE)
                    loop$.fraction[loop$.lambda == uniqueLambda[i]] <- subFrac[which.max(subFrac)]
                    seqParam[[i]] <- data.frame(.fraction = subFrac[-which.max(subFrac)])
                  }         
+             },
+             lasso = 
+             {
+               grid <- grid[order(grid$.fraction, decreasing = TRUE),, drop = FALSE]
+               loop <- grid[1,,drop = FALSE]
+               seqParam <- list(grid[-1,,drop = FALSE])
              }     
              )
       out <- list(scheme = "seq", loop = loop, seqParam = seqParam, model = modelInfo, constant = constant, vary = vary)
