@@ -150,9 +150,9 @@
                  lm =, nnet =, multinom =, pls =, earth =, 
                  bagEarth =, bagFDA = print(summary(x$finalModel)),
                  
-                 rpart =, ctree =, cforest =,
+                 rpart =, ctree =, ctree2=, cforest =,
                  glmboost =, gamboost =, blackboost =,
-                 ada =, randomForest =,
+                 ada =, randomForest =, pcaNNet =,
                  svmradial =, svmpoly =, enet =, lasso =,
                  lda =, rda =, pamr =, gpls = print(x$finalModel),
                  fda = 
